@@ -2,7 +2,7 @@ package RedisDB;
 
 use strict;
 use warnings;
-our $VERSION = "1.04";
+our $VERSION = "1.05";
 $VERSION = eval $VERSION;
 
 use RedisDB::Error;
@@ -533,16 +533,18 @@ sub version {
 my @commands = qw(
   append	auth	bgrewriteaof	bgsave	blpop	brpop   brpoplpush	config_get
   config_set	config_resetstat	dbsize	debug_object	debug_segfault
-  decr	decrby	del	echo	exists	expire	expireat	flushall
+  decr	decrby	del	echo	eval    evalsha exists	expire	expireat	flushall
   flushdb	get	getbit	getrange	getset	hdel	hexists	hget	hgetall
-  hincrby	hkeys	hlen	hmget	hmset	hset	hsetnx	hvals	incr	incrby
-  keys	lastsave	lindex	linsert	llen	lpop	lpush	lpushx
-  lrange	lrem	lset	ltrim	mget	move	mset	msetnx	persist	ping
+  hincrby	hincrbyfloat	hkeys	hlen	hmget	hmset	hset	hsetnx	hvals	incr	incrby
+  incrbyfloat	keys	lastsave	lindex	linsert	llen	lpop	lpush	lpushx
+  lrange	lrem	lset	ltrim	mget	move	mset	msetnx	persist
+  pexpire	pexpireat	psetex	pttl	ping
   publish	quit	randomkey	rename	renamenx	rpop	rpoplpush
-  rpush	rpushx	sadd	save	scard	sdiff	sdiffstore	select	set
+  rpush	rpushx	sadd	save	scard	script_exists   script_flush    script_kill
+  script_load   sdiff	sdiffstore	select	set
   setbit	setex	setnx	setrange	sinter	sinterstore
   sismember	slaveof	smembers	smove	sort	spop	srandmember
-  srem	strlen	sunion	sunionstore	sync	ttl	type	unwatch watch
+  srem	strlen	sunion	sunionstore	sync	time    ttl	type	unwatch watch
   zadd	zcard
   zcount	zincrby	zinterstore	zrange	zrangebyscore	zrank	zrem
   zremrangebyrank   zremrangebyscore	zrevrange	zrevrangebyscore	zrevrank
@@ -569,18 +571,20 @@ I<execute>, waits for the reply from the server, and returns it. E.g.:
     $redis->send_command("get", $key, sub { $val = $_[1] });
 
 The following wrapper methods are defined: append, auth, bgrewriteaof, bgsave,
-blpop, brpop, brpoplpush, config_get, config_set, config_resetstat, dbsize,
-debug_object, debug_segfault, decr, decrby, del, echo, exists, expire,
-expireat, flushall, flushdb, get, getbit, getrange, getset, hdel, hexists,
-hget, hgetall, hincrby, hkeys, hlen, hmget, hmset, hset, hsetnx, hvals, incr,
-incrby, keys, lastsave, lindex, linsert, llen, lpop, lpush, lpushx, lrange,
-lrem, lset, ltrim, mget, move, mset, msetnx, persist, ping, publish, quit,
+blpop, brpop,   brpoplpush, config_get, config_set, config_resetstat, dbsize,
+debug_object, debug_segfault, decr, decrby, del, echo, eval,    evalsha,
+exists, expire, expireat, flushall, flushdb, get, getbit, getrange, getset,
+hdel, hexists, hget, hgetall, hincrby, hincrbyfloat, hkeys, hlen, hmget, hmset,
+hset, hsetnx, hvals, incr, incrby, incrbyfloat, keys, lastsave, lindex,
+linsert, llen, lpop, lpush, lpushx, lrange, lrem, lset, ltrim, mget, move,
+mset, msetnx, persist, pexpire, pexpireat, psetex, pttl, ping, publish, quit,
 randomkey, rename, renamenx, rpop, rpoplpush, rpush, rpushx, sadd, save, scard,
-sdiff, sdiffstore, select, set, setbit, setex, setnx, setrange, sinter,
-sinterstore, sismember, slaveof, smembers, smove, sort, spop, srandmember,
-srem, strlen, sunion, sunionstore, sync, ttl, type, unwatch, watch, zadd,
-zcard, zcount, zincrby, zinterstore, zrange, zrangebyscore, zrank, zrem,
-zremrangebyrank, zremrangebyscore, zrevrange, zrevrangebyscore, zrevrank,
+script_exists,   script_flush,    script_kill, script_load,   sdiff,
+sdiffstore, select, set, setbit, setex, setnx, setrange, sinter, sinterstore,
+sismember, slaveof, smembers, smove, sort, spop, srandmember, srem, strlen,
+sunion, sunionstore, sync, time,    ttl, type, unwatch, watch, zadd, zcard,
+zcount, zincrby, zinterstore, zrange, zrangebyscore, zrank, zrem,
+zremrangebyrank,   zremrangebyscore, zrevrange, zrevrangebyscore, zrevrank,
 zscore, zunionstore
 
 See description of all commands in redis documentation at
@@ -633,7 +637,7 @@ answer.  Croaks in case of the error.
 
 sub shutdown {
     my $self = shift;
-    $self->send_command_cb('SHUTDOWN');
+    $self->send_command_cb('SHUTDOWN', @_);
     return;
 }
 
